/* version.h: defines version number and release date */

#ifndef _version_h_
#define _version_h_

#define MAJOR_VERSION 1
#define MINOR_VERSION 00

#define RELEASE_DATE "May 6, 1999"

#endif /* _version_h_ */
